Welcome to ISLP documentation!
==============================

.. automodule:: ISLP

See the :doc:`api/index`

Contents
--------

.. toctree::

   installation
   data
   transforms
   models
   helpers
   labs
   imdb

